@@ -14,17 +14,20 @@ module CCK
     end
 
     def compare
-      return [] if identical_keys?
+      return if identical_keys?
+      return "Detected extra keys in message #{message_name}: #{extra_keys}" if extra_keys.any?
 
-      errors << "Detected extra keys in message #{message_name}: #{extra_keys}" if extra_keys.any?
-      errors << "Missing keys in message #{message_name}: #{missing_keys}" if missing_keys.any?
-      errors
+      "Missing keys in message #{message_name}: #{missing_keys}" if missing_keys.any?
     rescue StandardError => e
       ["Unexpected error: #{e.message}"]
     end
 
     private
 
+    def identical_keys?
+      detected_keys == expected_keys
+    end
+
     def detected_keys
       @detected_keys ||= ordered_uniq_hash_keys(detected)
     end
@@ -33,18 +36,18 @@ module CCK
       @expected_keys ||= ordered_uniq_hash_keys(expected)
     end
 
-    def identical_keys?
-      detected_keys == expected_keys
-    end
-
-    def missing_keys
-      (expected_keys - detected_keys).reject { |key| meta_message? && key == :ci }
+    def ordered_uniq_hash_keys(object)
+      object.to_h(reject_nil_values: true).keys.sort
     end
 
     def extra_keys
       (detected_keys - expected_keys).reject { |key| meta_message? && key == :ci }
     end
 
+    def missing_keys
+      (expected_keys - detected_keys).reject { |key| meta_message? && key == :ci }
+    end
+
     def meta_message?
       detected.instance_of?(Cucumber::Messages::Meta)
     end
@@ -52,13 +55,5 @@ module CCK
     def message_name
       detected.class.name
     end
-
-    def ordered_uniq_hash_keys(object)
-      object.to_h(reject_nil_values: true).keys.sort
-    end
-
-    def errors
-      @errors ||= []
-    end
   end
 end
